export declare const ait3Template = "# AIT\u00B3 - AI-Driven Development Platform\n\nAIT\u00B3 implements a disciplined AI + Ticket + Test + Tool driven development workflow. Each phase must be completed before proceeding to the next.\n\n## Core Commands\n\n### Ticket Management\n```bash\nait3 ticket create \"Feature name\"     # Create new ticket\nait3 ticket list                      # List all tickets\nait3 ticket show <id>                 # View ticket details\nait3 ticket start <id>                # Start working on ticket\nait3 ticket complete <id>             # Mark ticket as done\nait3 ticket undo <id>                 # Undo ticket to previous state\nait3 ticket delete <id>               # Delete a ticket (with --dry-run option)\n```\n\n### Setup & Configuration\n```bash\nait3 setup ticket github              # Configure GitHub Issues backend\nait3 setup ticket local               # Configure local file backend\nait3 migrate local github             # Migrate tickets between backends\nait3 migrate github local --tickets \"1,3-5\"  # Migrate specific tickets\n```\n\n### Project Analysis & Installation\n```bash\nait3 init                             # Generate 3 files for Claude Code integration\nait3 install command                  # Install Claude Code command guides\nait3 install security                 # Add security permissions to settings.local.json\nait3 analyze project                  # Analyze project structure and dependencies\n```\n\n### AIT\u00B3 Workflow (MANDATORY SEQUENCE)\n\n#### 1. PLANNING Phase - Socratic Dialogue\n```bash\nait3 flow plan <ticketId> [options]\n```\n**Purpose**: Validate approach through dialectical reasoning BEFORE any implementation.\n\n**Process**:\n1. Claude proposes implementation approach with rationale\n2. Challenge with Gemini: `gemini -p \"Critique this approach: [details]\"`\n3. Human synthesizes competing perspectives and decides\n4. Document decision reasoning in commit message\n\n**IMPORTANT**: Never skip this phase. Failed refutations strengthen confidence.\n\n#### 2. RED Phase - Test Creation\n```bash\nait3 flow red <ticketId>\n```\n**Purpose**: Create comprehensive failing tests that define expected behavior.\n\n**Requirements**:\n- Tests MUST reflect ticket requirements, not implementation details\n- All tests MUST fail initially (0% pass rate)\n- Cover edge cases, error conditions, and happy paths\n- Tests drive implementation, not vice versa\n\n#### 3. GREEN Phase - Implementation\n```bash\nait3 flow green <ticketId>\n```\n**Purpose**: Write minimal code to achieve 100% test pass rate.\n\n**Constraints**:\n- Achieve 100% test pass rate (non-negotiable)\n- Minimal implementation only (no gold-plating)\n- Mock external dependencies when needed\n- Create tickets for mock implementations requiring real code\n\n#### 4. REFACTOR Phase - Optimization\n```bash\nait3 flow refactor <ticketId>\n```\n**Purpose**: Improve code quality while maintaining 100% test coverage.\n\n**Focus Areas**:\n- Extract common patterns and utilities\n- Identify and ticket mock implementations\n- Optimize performance bottlenecks\n- Improve error handling and logging\n- Enhance code readability\n\n#### 5. SQUASH Phase - Git Integration\n```bash\nait3 flow squash <ticketId>\n```\n**Purpose**: Provide Git command suggestions for clean commit history.\n\n**Output**:\n- Interactive rebase commands\n- Commit message templates\n- Safe push commands (--force-with-lease)\n- PR creation commands (with --pr flag)\n- Merge workflow guidance\n\n**Note**: Commands are suggestions only. Human executes manually.\n\n## AIT\u00B3 Philosophy\n\n### Socratic Foundation\nWisdom emerges through questioning and dialogue. Embrace \"I may know nothing\" as the starting point.\n\n### Dialectical Process\n1. **Thesis** (Claude): Propose solution with reasoning\n2. **Antithesis** (Gemini): Challenge assumptions and identify flaws\n3. **Synthesis** (Human): Make informed decision\n\n### Core Principles\n- **Counterarguments are treasures**, not threats\n- **Failed refutations strengthen confidence**\n- **Successful refutations prevent bugs**\n- **Human judgment remains supreme**\n- **Tests define behavior, not implementation**\n\n## Workflow Example\n\n```bash\n# 1. Create and start ticket\nait3 ticket create \"Add user authentication\"\nait3 ticket start 0001\n\n# 2. PLANNING - Validate approach\nait3 flow plan 0001\n# Claude proposes JWT approach\n# Challenge: gemini -p \"@src/ Critique JWT auth approach\"\n# Human decides based on both perspectives\n\n# 3. RED - Create failing tests\nait3 flow red 0001\n# Write tests for auth endpoints, token validation, etc.\n# Verify 0% pass rate\n\n# 4. GREEN - Implement to pass tests\nait3 flow green 0001\n# Write minimal code for 100% pass rate\n# Mock email service \u2192 create ticket #0002\n\n# 5. REFACTOR - Optimize implementation\nait3 flow refactor 0001\n# Extract auth utilities, improve error handling\n# Maintain 100% test coverage\n\n# 6. SQUASH - Clean Git history\nait3 flow squash 0001\n# Review suggested Git commands\n# Execute manually with adjustments\n\n# 7. Complete ticket\nait3 ticket complete 0001\n```\n\n## Critical Rules\n\n1. **NEVER skip phases** - Each phase serves a specific purpose\n2. **NEVER modify tests to fit implementation** - Tests drive code\n3. **NEVER accept <100% test pass in GREEN** - Non-negotiable\n4. **NEVER implement without PLANNING** - Validate approach first\n5. **ALWAYS document reasoning** - Future you will thank you\n\n## Best Practices\n\n- Use tickets for context management (LLM limitations)\n- One ticket = one feature/fix (maintain focus)\n- Create sub-tickets for discovered work\n- Commit messages should include decision rationale\n- Review Gemini critiques seriously, even if you disagree\n\n## GitHub Integration (v1.1+)\n\n### Initial Setup\n```bash\n# Configure GitHub Issues backend\nait3 setup ticket github\n\n# Auto-detects repository from git remote\n# Validates gh CLI authentication\n# Stores configuration in .tickets/config.json\n```\n\n### Ticket Backend Switching\n```bash\n# Switch to GitHub Issues\nait3 setup ticket github\n\n# Switch back to local files\nait3 setup ticket local\n\n# Migrate existing tickets\nait3 migrate local github        # All tickets\nait3 migrate local github --tickets \"1,3-5\"  # Specific tickets\n```\n\n### Requirements\n- GitHub CLI (`gh`) installed and authenticated\n- Repository access permissions\n- Issues enabled on GitHub repository\n\n## Integration Tips\n\n- Works with any language/framework\n- Compatible with existing test runners\n- Integrates with standard Git workflows\n- Supports CI/CD pipelines\n- Language-agnostic principles\n- Seamless local \u2194 GitHub ticket management\n\nRemember: The goal is thoughtful, evidence-based development through structured collaboration between human wisdom and AI capabilities.\n";
